about summary refs log tree commit diff
path: root/sysdeps/unix
diff options
context:
space:
mode:
authorMike Frysinger <vapier@gentoo.org>2010-09-01 12:45:02 -0700
committerUlrich Drepper <drepper@redhat.com>2010-09-01 12:45:02 -0700
commitfdc0c10d9b5c39ec20c35d2f3808d3c70cb7f60b (patch)
tree0d1be10e49fa084509e6395758e0ff3e9a201408 /sysdeps/unix
parente53a31fe575dcfd0dceb9f316d673de34d39abad (diff)
downloadglibc-fdc0c10d9b5c39ec20c35d2f3808d3c70cb7f60b.tar.gz
glibc-fdc0c10d9b5c39ec20c35d2f3808d3c70cb7f60b.tar.xz
glibc-fdc0c10d9b5c39ec20c35d2f3808d3c70cb7f60b.zip
Update sparc epoll.h from epoll_create2 to epoll_create1
Diffstat (limited to 'sysdeps/unix')
-rw-r--r--sysdeps/unix/sysv/linux/sparc/sys/epoll.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/sysdeps/unix/sysv/linux/sparc/sys/epoll.h b/sysdeps/unix/sysv/linux/sparc/sys/epoll.h
index cc0ddef69e..9943f21383 100644
--- a/sysdeps/unix/sysv/linux/sparc/sys/epoll.h
+++ b/sysdeps/unix/sysv/linux/sparc/sys/epoll.h
@@ -1,4 +1,4 @@
-/* Copyright (C) 2002-2006, 2007, 2008 Free Software Foundation, Inc.
+/* Copyright (C) 2002-2006, 2007, 2008, 2010 Free Software Foundation, Inc.
    This file is part of the GNU C Library.
 
    The GNU C Library is free software; you can redistribute it and/or
@@ -31,7 +31,7 @@ typedef __sigset_t sigset_t;
 #endif
 
 
 /* Flags to be passed to epoll_create2.  */
 enum
   {
     EPOLL_CLOEXEC = 0x400000,
@@ -101,8 +101,9 @@ __BEGIN_DECLS
    returned by epoll_create() should be closed with close().  */
 extern int epoll_create (int __size) __THROW;
 
-/* Same as epoll_create but with an additional FLAGS parameter.  */
-extern int epoll_create2 (int __size, int __flags) __THROW;
+/* Same as epoll_create but with an FLAGS parameter.  The unused SIZE
+   parameter has been dropped.  */
+extern int epoll_create1 (int __flags) __THROW;
 
 
 /* Manipulate an epoll instance "epfd". Returns 0 in case of success,
@@ -31,7 +31,7 @@ typedef __sigset_t sigset_t;
 
 
-/* Flags to be passed to epoll_create2.  */
+/* Flags to be passed to epoll_create1.  */
 enum
   {